@@ -1,4 +1,7 @@
-"""Constants module."""
+"""Constants module.
+
+https://en.wikipedia.org/wiki/International_System_of_Units
+"""
 
 import math as _math
 from . import base_units as _u
@@ -8,7 +11,6 @@ from . import base_units as _u
 _volt = (_u.kilogram * _u.meter**2) / (_u.ampere * _u.second**2)
 _coulomb = _u.second * _u.ampere
 _joule = _u.kilogram * _u.meter**2 / _u.second**2
-_pascal = _u.kilogram / (_u.meter * _u.second**2)
 
 
 # physical constants
@@ -30,10 +32,10 @@ reduced_planck_constant = 1.054571817e-34 * (_joule * _u.second)
 
 # --- measured ---
 
-# 2021-04-15 - https://physics.nist.gov/cgi-bin/cuu/Value?me|search_for=electron+mass
+# 2022-03-19 - https://physics.nist.gov/cgi-bin/cuu/Value?me|search_for=electron+mass
 electron_mass = 9.1093837015e-31 * (_u.kilogram)
 
-# 2021-04-15 - https://physics.nist.gov/cgi-bin/cuu/Value?mu0|search_for=vacuum+permeability
+# 2022-03-19 - https://physics.nist.gov/cgi-bin/cuu/Value?mu0|search_for=vacuum+permeability
 vacuum_permeability = 1.25663706212e-6 * \
     (_volt * _u.second / _u.ampere / _u.meter)
 
